<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version = "1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				      xmlns="http://www.w3.org/1999/xhtml">
<!-- Folgende Namespaces werden gebraucht, falls man xsl:script verwenden moechte.
				xmlns:msxsl="urn:schemas-microsoft-com:xslt"
				xmlns:bka="http://www.bka.gv.at" -->
<!--
 /////////////////////////////////////////////////////////////////
  Autor:       Hermann Anderl
  Revision:    1.2
  Erstellt:    03.10.2003
  Modifiziert: 18.12.2003
 ///////////////////////////////////////////////////////////////// -->
<xsl:output method="xml" encoding="ISO-8859-1" doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd" doctype-public="-//W3C//DTD XHTML 1.1//EN" indent="yes"/>

<!-- Auf folgende Weise kann man JScript-Funktionen einbinden: -->
<!--
<msxsl:script language="JScript" implements-prefix="bka">
   function replace(old) { return old.replace(/\./,"_"); }
</msxsl:script>
-->

<!--
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ////
 //// Bei der Erstellung dieses Stylesheets wurden folgende Kriterien angewandt:
 ////
 //// 1.) Es wurde darauf geachtet folgende HTML-Elemente bzw. Attribute zu vermeiden, weil diese durch
 ////      CSS-Stylesheets abgedeckt werden knnen:
 ////      font, color, hr, h1, h2, h3, h4, h5, h6, sub, sup, i, b.
 ////
 //// 2.) Die Attribute align bzw. valign wurden nur in folgenden Situatonen verwendet:
 ////      a) innerhalb von Tabellen
 ////      b) in Situationen in denen eine im XML-Dokument angegebene Ausrichtung weiter gereicht werden muss.
 ////      An allen anderen Stellen erfolgt die Ausrichtung des Textes anhand der Angaben in den CSS-Stylesheets.
 ////
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// -->

<!--
 /////////////////////////////////////////////////////////////////
 //// Keys
 ///////////////////////////////////////////////////////////////// -->
<xsl:key name="key_ueberschrift_typ" match="ueberschrift" use="@typ"/>
<xsl:key name="key_kzinhalt_typ" match="kzinhalt" use="@typ"/>
<xsl:key name="key_fzinhalt_typ" match="fzinhalt" use="@typ"/>

<!--
 /////////////////////////////////////////////////////////////////
 //// Aufbau des XHTML-Dokuments
 /////////////////////////////////////////////////////////////////-->
<xsl:template match="/">
  <xsl:element name="html">
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>
<!-- ////////////////////////////////////////////////////////////////// -->
<xsl:template match="metadaten">
    <xsl:element name="head">
      <xsl:element name="title">eRecht XHTML 1.1 Dokument</xsl:element>
      <xsl:element name="style">
      <xsl:attribute name="type">text/css</xsl:attribute>
      <!-- In der folgenden Schleife wird fuer alle width-Attribute die in td-Elementen vorkommen eine CSS-Klasse generiert.
           Da im Namen einer CSS-Klasse keine Punkte vorkommen duerfen, werden diese mittels der Javascript-Funktion replace() durch Unterstriche ersetzt.-->
      <!--
      <xsl:for-each select="//td/@width">
        <xsl:value-of select="string('.W')"/><xsl:value-of select="bka:replace(string(.))"/><xsl:value-of select="string(' { width = ')"/><xsl:value-of select="."/><xsl:value-of select="string(' ;} ')"/>
      </xsl:for-each>
      -->
<!--PlaceHolder02For10CSS2003FileContent-->
        @import "d:\\bkatemp\\xml2html\\eRechtXML2XHTML11.css"; <!--DEBUG only-->
      </xsl:element>
    </xsl:element>
</xsl:template>
<!-- ////////////////////////////////////////////////////////////////// -->
<xsl:template match="nutzdaten">
  <xsl:element name="body">
    <xsl:attribute name="class">LegStandard</xsl:attribute>
    <xsl:variable name="layoutdaten" select = "//layoutdaten"></xsl:variable>
    <!-- Die Breiten sind in Points (pt) angegeben und werden so weitergereicht. -->
    <xsl:variable name="margt" select = "$layoutdaten/@margt"></xsl:variable>
    <xsl:variable name="margr" select = "$layoutdaten/@margr"></xsl:variable>
    <xsl:variable name="margb" select = "$layoutdaten/@margb"></xsl:variable>
    <xsl:variable name="margl" select = "$layoutdaten/@margl"></xsl:variable>
    <xsl:variable name="paperwidth" select = "$layoutdaten/@paperw"></xsl:variable>
    <xsl:if test="$layoutdaten/@margt | $layoutdaten/@margr | $layoutdaten/@margb | $layoutdaten/@margl">
      <xsl:attribute name="style">
        <xsl:if test="$layoutdaten/@margt">
          <xsl:value-of select="concat('margin-top:', $margt, 'pt;')"/>
        </xsl:if>
        <xsl:if test="$layoutdaten/@margr">
          <xsl:value-of select="concat('margin-right:', $margr, 'pt;')"/>
        </xsl:if>
        <xsl:if test="$layoutdaten/@margb">
          <xsl:value-of select="concat('margin-bottom:', $margb, 'pt;')"/>
        </xsl:if>
        <xsl:if test="$layoutdaten/@margl">
          <xsl:value-of select="concat('margin-left:', $margl, 'pt;')"/>
        </xsl:if>
      </xsl:attribute>
    </xsl:if>
    <xsl:element name="table">
      <xsl:if test="$layoutdaten/@paperw">
        <xsl:attribute name="width"><xsl:value-of select = "$paperwidth"/>pt</xsl:attribute>
      </xsl:if>
      <xsl:element name="tr">
        <xsl:if test="$layoutdaten/@paperw">
          <xsl:attribute name="style"><xsl:value-of select="string('width=')"/><xsl:value-of select="$paperwidth"/><xsl:value-of select="string('pt;')"/></xsl:attribute>
          <!-- In XHTML1.1 ist das width-Attribut nicht beim tr-Element erlaubt. -->
          <!--xsl:attribute name="width"><xsl:value-of select = "$paperwidth"/>pt</xsl:attribute-->
        </xsl:if>      
        <xsl:element name="td">
          <xsl:if test="$layoutdaten/@paperw">
          <xsl:attribute name="style"><xsl:value-of select="string('width=')"/><xsl:value-of select="$paperwidth"/><xsl:value-of select="string('pt;')"/></xsl:attribute>
          <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
          <!--xsl:attribute name="width"><xsl:value-of select = "$paperwidth"/>pt</xsl:attribute-->
          </xsl:if>
          <xsl:apply-templates select="key('key_kzinhalt_typ', 'f')[1]" mode="dokumentanfang"/>
          <xsl:apply-templates/>
          <xsl:apply-templates select="//fnen" mode="dokumentende"/>
          <xsl:apply-templates select="key('key_fzinhalt_typ', 'f')[1]" mode="dokumentende"/>
          <!--      <xsl:apply-templates select="//fzinhalt" mode="dokumentende"/> -->
        </xsl:element>
      </xsl:element>
    </xsl:element>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Ausgabedaten
 ///////////////////////////////////////////////////////////////// -->
<xsl:template match="ausgabe">
  <xsl:element name="table">
    <xsl:attribute name="width">100%</xsl:attribute>
    <xsl:attribute name="class">top bottom</xsl:attribute>
<!--  <xsl:attribute name="border">1</xsl:attribute> -->
    <xsl:element name="tr">
      <xsl:apply-templates mode="erzeuge_ausgabe"/>
    </xsl:element>
  </xsl:element>
</xsl:template>

<xsl:template match="adtext" mode="erzeuge_ausgabe">
  <xsl:element name="td">
    <xsl:attribute name="align">left</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class">AusgabeDaten</xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:element>
</xsl:template>

<xsl:template match="addat" mode="erzeuge_ausgabe">
  <xsl:element name="td">
    <xsl:attribute name="align">center</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class">AusgabeDaten</xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:element>
</xsl:template>

<xsl:template match="adid" mode="erzeuge_ausgabe">
  <xsl:element name="td">
    <xsl:attribute name="align">right</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class">AusgabeDaten</xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Kurztitel
 ///////////////////////////////////////////////////////////////// -->
<xsl:template match="*" mode="erzeuge_zeilen"></xsl:template><!-- nichts tun -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="key('key_ueberschrift_typ', 'kurztitel')" mode="erzeuge_zeilen">
      <xsl:element name="tr">
        <xsl:if test="tab[1]">
          <xsl:element name="td">
            <xsl:attribute name="align">left</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class">Kurztitel2</xsl:attribute>
              <xsl:element name="span">
                <xsl:attribute name="class">Kurztitelbreite</xsl:attribute>
                <!-- Verarbeite nun alles was vor dem 1. Tabulator kommt. -->
                <!-- tab[1]/preceding-sibling::text() bewirkt die Verarbeitung aller Textknoten vor dem 1. Tab. -->
                <!-- tab[1]/preceding-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
                <xsl:for-each select="tab[1]/preceding-sibling::text() | tab[1]/preceding-sibling::*">
                  <xsl:apply-templates select="."/>
                </xsl:for-each>
              </xsl:element>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">left</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class">Kurztitel2</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem 1. Tabulator. -->
            <!-- tab[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem 1. Tab. -->
            <!-- tab[1]/following-sibling::* bewirkt die Verarbeitung der restlichen Tabulatoren und enthaltener Subknoten. -->
            <xsl:for-each select="tab[1]/following-sibling::text() | tab[1]/following-sibling::*">
              <xsl:apply-templates select="."/>
            </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:if>
        <xsl:if test="not(tab[1])">
          <!-- Da es keinen Tabulator gibt, wird nur eine Spalte erzeugt. -->
          <xsl:element name="td">
            <xsl:attribute name="align">left</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:attribute name="colspan">2</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class">Kurztitel1</xsl:attribute>
                <xsl:apply-templates/>
            </xsl:element>
          </xsl:element>
        </xsl:if>
      </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Inhaltsverzeichnis, HTML-Tabellen ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="inhaltsvz ">
  <xsl:choose >
    <xsl:when test="./@typ='ueberschrift'">
      <p class='InhaltUeberschrift'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='spalte'">
      <p class='InhaltSpalte'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='eintrag'">
      <p class='InhaltEintrag'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="table">
    <xsl:element name="table">
      <xsl:apply-templates select="./@*"/>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="tr">
    <xsl:element name="tr">
      <xsl:apply-templates select="./@*"/>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="td">
    <xsl:element name="td">
      <xsl:apply-templates select="./@*"/>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@border">
  <xsl:attribute name="border"><xsl:value-of select = "." /></xsl:attribute>
<!--  <xsl:attribute name="border">1</xsl:attribute> -->
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@cellspacing">
  <xsl:attribute name="cellspacing"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@cellpadding">
  <xsl:attribute name="cellpadding"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@colspan">
  <xsl:attribute name="colspan"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@rowspan">
  <xsl:attribute name="rowspan"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@width">
  <xsl:choose >
    <xsl:when test="ancestor::td">
      <xsl:attribute name="style"><xsl:value-of select="string('width=')"/><xsl:value-of select="."/><xsl:value-of select="string(';')"/></xsl:attribute>
      <!-- Falls die direkte Angabe eines style-Attributs nicht erwuenscht ist, kann man folgendes Statement verwenden um ueber das class-Attribut -->
      <!-- eine passende CSS-Klasse anzusprechen. -->
      <!--xsl:attribute name="class"><xsl:value-of select = "string('W')"/><xsl:value-of select = "bka:replace(string(.))" /></xsl:attribute-->
    </xsl:when>
    <xsl:when test="ancestor::tr">
      <xsl:attribute name="style"><xsl:value-of select="string('width=')"/><xsl:value-of select="."/><xsl:value-of select="string(';')"/></xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <!-- Das width-Attribut wird einfach weiter gereicht. -->
      <xsl:attribute name="width"><xsl:value-of select = "." /></xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@height">
  <xsl:choose >
    <xsl:when test="ancestor::td">
      <xsl:attribute name="style"><xsl:value-of select="string('height=')"/><xsl:value-of select="."/><xsl:value-of select="string(';')"/></xsl:attribute>
    </xsl:when>
    <xsl:when test="ancestor::tr">
      <xsl:attribute name="style"><xsl:value-of select="string('height=')"/><xsl:value-of select="."/><xsl:value-of select="string(';')"/></xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <!-- Das height-Attribut wird einfach weiter gereicht. -->
      <xsl:attribute name="height"><xsl:value-of select = "." /></xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@align">
  <xsl:attribute name="align"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@valign">
  <xsl:attribute name="valign"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@style">
  <!-- noch nicht fertig - Es muss noch beim BKA nachgefragt werden, ob wird das Attribut style doch verwenden drfen! -->
  <xsl:attribute name="style"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@class">
  <xsl:attribute name="class"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@h-start"><!-- nichts tun -->
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@h-xval"><!-- nichts tun -->
</xsl:template>

<xsl:template name="checkForEmptyCell">
  <xsl:if test="ancestor::table">
    <xsl:if test=". = ''"><xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/></xsl:if>
  </xsl:if>
  <xsl:apply-templates/>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Ueberschriften                                ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="ueberschrift">
  <xsl:choose >
    <xsl:when test="./@typ='bdgesblatt'">
      <p class='BDGesBlatt'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='repoesterr'">
      <p class='RepOesterr'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='entwurf'">
      <p class='Entwurf'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='kurztitel'">
      <xsl:if test="not(name(preceding-sibling::*[1]) = 'ueberschrift')">
      <xsl:element name="table">
        <xsl:attribute name="width">100%</xsl:attribute>
        <xsl:attribute name="class">bottom</xsl:attribute>
<!--        <xsl:attribute name="border">1</xsl:attribute> -->
<!--        <xsl:attribute name="parent"><xsl:value-of select="name(parent::*)"/></xsl:attribute>
        <xsl:attribute name="preceding"><xsl:value-of select="name(preceding::*)"/></xsl:attribute>
        <xsl:attribute name="preceding-sibling"><xsl:value-of select="name(preceding-sibling::*)"/></xsl:attribute>
        <xsl:attribute name="preceding-sibling-typ"><xsl:value-of select="preceding-sibling::*/@typ"/></xsl:attribute>
        <xsl:attribute name="count-preceding-sibling"><xsl:value-of select="count(preceding-sibling::*)"/></xsl:attribute>
        <xsl:attribute name="count-preceding"><xsl:value-of select="count(preceding::*)"/></xsl:attribute>
        <xsl:attribute name="yyy-sibling-typ"><xsl:value-of select="name(preceding-sibling::*[1])"/></xsl:attribute>
        <xsl:attribute name="zzz-sibling-typ"><xsl:value-of select="name(preceding::*[1])"/></xsl:attribute> -->
        <xsl:apply-templates select="../ueberschrift" mode="erzeuge_zeilen"/>
      </xsl:element>
      </xsl:if>
    </xsl:when>
    <xsl:when test="./@typ='titel'">
      <p class='Titel'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='g1'">
      <p class='UeberschrG1'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='g2'">
      <p class='UeberschrG2'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='g1min'">
      <p class='UeberschrG1-'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='art'">
      <p class='UeberschrArt'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='para'">
      <p class='UeberschrPara'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='anlage'">
      <p class='Anlagenbez'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='erlz'">
      <p class='ErlUeberschrZ'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='erll'">
      <p class='ErlUeberschrL'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='tgue'">
      <p class='TGUEUeberschrSpalte'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Absaetze                                        ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="absatz">
  <xsl:choose >
    <xsl:when test="./@typ='undef'">
      <p class='Undefiniert'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='promkleinlsatz'">
      <p class='PromKlEinlSatz'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='abs'">
      <p class='Abs'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='abbobj'">
      <xsl:element name="p">
        <xsl:choose >
          <xsl:when test="./@halign='left'">
            <xsl:attribute name="class">AbbildungoderObjektL</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:when>
          <xsl:when test="./@halign='center'">
            <xsl:attribute name="class">AbbildungoderObjektZ</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:when>
          <xsl:when test="./@halign='right'">
            <xsl:attribute name="class">AbbildungoderObjektR</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="class">AbbildungoderObjekt</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='novao1'">
      <p class='NovAo1'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='novao2'">
      <p class='NovAo2'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='satz'">
      <p class='SatznachNovao'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='tabtext'">
      <p class='TabText'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='tabtextr'">
      <p class='TabTextRechtsb'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='tabtextz'">
      <p class='TabTextZentriert'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='tabtextb'">
      <p class='TabTextBlock'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='erltext'">
      <p class='ErlText'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='kz'">
      <p class='Kopfzeile'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='fz'">
      <p class='Fusszeile'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="abstand">
      <p class='Abstand'><xsl:call-template name="checkForEmptyCell"/></p>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Normale Liste                                  ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="liste">
    <xsl:element name="table">
      <xsl:attribute name="width">100%</xsl:attribute>
<!--      <xsl:attribute name="border">1</xsl:attribute> -->
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="ziffernliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">ZifferE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">ZifferE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">ZifferE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falsche Ebene: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="literaliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">LiteraE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">LiteraE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">LiteraE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falsche Ebene: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="subliteraliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">SubliteraE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">SubliteraE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">SubliteraE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falsche Ebene: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="strichliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">StrichE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">StrichE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">StrichE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='4'">
      <xsl:apply-templates mode="erzeuge_liste_ebene4">
        <xsl:with-param name="classname">StrichE4</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falsche Ebene: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene1">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:attribute name="style"><xsl:value-of select="string('width=38;')"/></xsl:attribute>
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
            <!--xsl:attribute name="width">38</xsl:attribute-->
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">7</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene2">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td"/>
          <xsl:element name="td">
            <xsl:attribute name="style"><xsl:value-of select="string('width=15;')"/></xsl:attribute>
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
            <!--xsl:attribute name="width">15</xsl:attribute-->
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">6</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene3">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td"/>
          <xsl:element name="td"/>
          <xsl:element name="td">
            <xsl:attribute name="style"><xsl:value-of select="string('width=22;')"/></xsl:attribute>
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
            <!--xsl:attribute name="width">22</xsl:attribute-->
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">5</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene4">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td"/>
          <xsl:element name="td"/>
          <xsl:element name="td"/>
          <xsl:element name="td">
            <xsl:attribute name="style"><xsl:value-of select="string('width=22;')"/></xsl:attribute>
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
            <!--xsl:attribute name="width">22</xsl:attribute-->
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">4</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:apply-templates select="."/>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="schluss">
  <xsl:choose >
    <xsl:when test="./@typ='Abs'">
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">8</xsl:attribute>
            <p class='SchlussteilAbs'><xsl:call-template name="checkForEmptyCell"/></p>
          </xsl:element>
        </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='Ziff'">
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:attribute name="style"><xsl:value-of select="string('width=38;')"/></xsl:attribute><!-- wie Ebene 1 -->
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
            <!--xsl:attribute name="width">38</xsl:attribute--><!-- wie Ebene 1 -->
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">7</xsl:attribute>
            <p class='SchlussteilZiff'><xsl:call-template name="checkForEmptyCell"/></p>
          </xsl:element>
        </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='Lit'">
        <xsl:element name="tr">
          <xsl:element name="td"/>
          <xsl:element name="td">
            <xsl:attribute name="style"><xsl:value-of select="string('width=15;')"/></xsl:attribute><!-- wie Ebene 2 -->
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
            <!--xsl:attribute name="width">15</xsl:attribute--><!-- wie Ebene 2 -->
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">6</xsl:attribute>
            <p class='SchlussteilLit'><xsl:call-template name="checkForEmptyCell"/></p>
          </xsl:element>
        </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Betragliste                                      ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="betragliste">
  <xsl:choose >
    <xsl:when test="./@typ='ziffer'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene1">
        <xsl:with-param name="classname">ZifferMitBetrag</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='litera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene2">
        <xsl:with-param name="classname">LiteraMitBetrag</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='sublitera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene3">
        <xsl:with-param name="classname">SubliteraMitBetrag</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="betraglistetgue">
  <xsl:choose >
    <xsl:when test="./@typ='ziffer'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene1">
        <xsl:with-param name="classname">ZifferMitBetragTGUE</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='litera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene2">
        <xsl:with-param name="classname">LiteraMitBetragTGUE</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='sublitera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene3">
        <xsl:with-param name="classname">SubliteraMitBetragTGUE</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_betragliste_ebene1">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td">
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">5</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:if test="name() = 'tab'">
                  <xsl:value-of select="string('&lt;/p&gt;&lt;/td&gt;&lt;td&gt;&lt;p class=&quot;')" disable-output-escaping="yes"/>
                  <xsl:value-of select = "$classname"/><xsl:value-of select="string('&quot;&gt;')" disable-output-escaping="yes"/>
                </xsl:if>
                <xsl:if test="name() != 'tab'">
                  <xsl:apply-templates select="."/>
                </xsl:if>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_betragliste_ebene2">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td"/>
          <xsl:element name="td">
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">4</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:if test="name() = 'tab'">
                  <xsl:value-of select="string('&lt;/p&gt;&lt;/td&gt;&lt;td&gt;&lt;p class=&quot;')" disable-output-escaping="yes"/>
                  <xsl:value-of select = "$classname"/><xsl:value-of select="string('&quot;&gt;')" disable-output-escaping="yes"/>
                </xsl:if>
                <xsl:if test="name() != 'tab'">
                  <xsl:apply-templates select="."/>
                </xsl:if>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_betragliste_ebene3">
  <xsl:param name = "classname"/>
        <xsl:element name="tr">
          <xsl:element name="td"/>
          <xsl:element name="td"/>
          <xsl:element name="td">
            <xsl:attribute name="align">right</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:apply-templates select="symbol[1]"/>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">justify</xsl:attribute>
            <xsl:attribute name="colspan">3</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
            <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
            <xsl:element name="p">
              <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
              <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
                <xsl:if test="name() = 'tab'">
                  <xsl:value-of select="string('&lt;/p&gt;&lt;/td&gt;&lt;td&gt;&lt;p class=&quot;')" disable-output-escaping="yes"/>
                  <xsl:value-of select = "$classname"/><xsl:value-of select="string('&quot;&gt;')" disable-output-escaping="yes"/>
                </xsl:if>
                <xsl:if test="name() != 'tab'">
                  <xsl:apply-templates select="."/>
                </xsl:if>
              </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Unterschrift                                     ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="unterschrift">
  <xsl:choose >
    <xsl:when test="./@typ='links'">
      <p class='UnterschrL'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:when test="./@typ='mitte'">
      <p class='UnterschrM'><xsl:call-template name="checkForEmptyCell"/></p>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Zeichenformatierung                       ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="error">
  <span class='Fehler'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="gldsym">
  <span class='GldSymbol'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="n">
  <span class='Normal'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="f | b">
  <span class='Fett'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="k | i">
  <span class='Kursiv'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="u">
  <span class='Unterstrichen'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="gs">
  <span class='Gesperrt'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="h | super">
  <span class='Hoch'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="t | sub">
  <span class='Tief'><xsl:apply-templates/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="fk">
  <span class='FettundKursiv'><xsl:apply-templates/></span>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Sonderzeichen                                ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="nbsp">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// doppeltes Anfhrungszeichen unten -->
<xsl:template match="bdquo">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#34;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// doppeltes Anfhrungszeichen oben -->
<xsl:template match="ldquo">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#34;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// Gedankenstrich -->
<xsl:template match="kidea">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#45;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// Bindestrich -->
<xsl:template match="gdash">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#45;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// Silbentrennzeichen -->
<xsl:template match="bdash"><!-- nichts tun -->
</xsl:template>

<xsl:template match="tab">
  <!-- Da weder in HTML noch in CSS2 Tabulatoren moeglich sind, wird ein Tabulator durch ein Blank ersetzt, das in span eingeschlossen ist. -->
  <span class='Standardtabulator'><xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/></span>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="euro">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;euro;')"/>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Verweise                                        ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="wwwlink">
  <xsl:element name="a">
    <xsl:apply-templates select="./@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@url">
  <xsl:attribute name="href"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////////////////
 //// Eingebettete base64-codierte Binrdaten   ////
 ///////////////////////////////////////////////////////////////////////////// -->

<!-- Alle Binrdateien werden in ein Unterverzeichnis ausgelagert. Das binary-Element mu ein ref-Attribut besitzen, das den relativen -->
<!-- Dateinamen der ausgelagerten Datei enthlt. -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="binary">
  <xsl:element name="img">
    <xsl:if test="./@ref">
      <xsl:if test="./@ref = ''">
        <xsl:attribute name="src"><xsl:value-of select = "string('.\unknown.')" /><xsl:value-of select = "./@datatype" /></xsl:attribute>
      </xsl:if>
      <xsl:if test="not(./@ref = '')">
        <xsl:attribute name="src"><xsl:value-of select = "./@ref" /></xsl:attribute>
      </xsl:if>
    </xsl:if>
    <xsl:if test="not(./@ref)">
      <xsl:attribute name="src"><xsl:value-of select = "string('.\unknown.')" /><xsl:value-of select = "./@datatype" /></xsl:attribute>
    </xsl:if>
    <xsl:attribute name="alt"><xsl:value-of select = "./@alt" /></xsl:attribute>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Beschriftung zu Grafiken                ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<!-- Da beim p-Element in XHTML kein align-Attribut erlaubt ist, wird mit mehreren CSS-Klassen fuer die Beschriftung gearbeitet. -->
<xsl:template match="beschr">
  <xsl:choose >
    <xsl:when test="./@typ='links'">
      <xsl:element name="p">
        <xsl:attribute name="class">BeschriftungL</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='mitte'">
      <xsl:element name="p">
        <xsl:attribute name="class">BeschriftungZ</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='rechts'">
      <xsl:element name="p">
        <xsl:attribute name="class">BeschriftungR</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:attribute name="class">Beschriftung</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Fu- und Endnoten                         ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// Fuzeilen sollen erst am Ende verarbeitet werden -->
<xsl:template match="fnen"><!-- nichts tun -->
</xsl:template>

<xsl:template match="fnen" mode="dokumentende">
      <xsl:apply-templates/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<!-- In XHTML1.1 darf beim anchor-Element nicht mehr das Attribut name verwendet werden, sondern da heisst es jetzt id. -->
<xsl:template match="fnzeichen">
  <xsl:choose >
    <xsl:when test="./@typ='f'">
      <xsl:element name="a">
        <xsl:attribute name="href"><xsl:value-of select = "string('#FN')" /><xsl:value-of select = "." /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select = "string('FNREF')" /><xsl:value-of select = "." /></xsl:attribute>
        <span class='FNZeichen'><xsl:value-of select = "string('[')" /><xsl:apply-templates/><xsl:value-of select = "string(']')" /></span>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='e'">
      <xsl:element name="a">
        <xsl:attribute name="href"><xsl:value-of select = "string('#EN')" /><xsl:value-of select = "." /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select = "string('ENREF')" /><xsl:value-of select = "." /></xsl:attribute>
        <span class='FNZeichen'><xsl:value-of select = "string('[')" /><xsl:apply-templates/><xsl:value-of select = "string(']')" /></span>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<!-- In XHTML1.1 darf beim anchor-Element nicht mehr das Attribut name verwendet werden, sondern da heisst es jetzt id. -->
<xsl:template match="fntext">
  <xsl:choose >
    <xsl:when test="./@typ='f'">
      <xsl:if test="./@nr = 1"><p class="FNLinie"/></xsl:if>
      <xsl:element name="p">
        <xsl:attribute name="class">FNText</xsl:attribute>
        <xsl:element name="a">
          <xsl:attribute name="href"><xsl:value-of select = "string('#FNREF')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <xsl:attribute name="id"><xsl:value-of select = "string('FN')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <span class='FNZeichen'><xsl:value-of select = "string('[')" /><xsl:value-of select = "./@nr" /><xsl:value-of select = "string(']')" /></span>
        </xsl:element>
        <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='e'">
      <xsl:if test="./@nr = 1"><p class="FNLinie"/></xsl:if>
      <xsl:element name="p">
        <xsl:attribute name="class">FNText</xsl:attribute>
        <xsl:element name="a">
          <xsl:attribute name="href"><xsl:value-of select = "string('#ENREF')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <xsl:attribute name="id"><xsl:value-of select = "string('EN')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <span class='FNZeichen'><xsl:value-of select = "string('[')" /><xsl:value-of select = "./@nr" /><xsl:value-of select = "string(']')" /></span>
        </xsl:element>
        <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Kopf- und Fuzeilen                       ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// Kopf- und Fuzeilen sollen an bestimmten Stellen verarbeitet werden und nicht dann wenn sie im XML-String vorkommen -->
<xsl:template match="kzinhalt | fzinhalt"><!-- nichts tun -->
</xsl:template>

<!--
<xsl:template match="fzinhalt" mode="dokumentende">
  <xsl:choose >
    <xsl:when test="./@typ='f'">
    </xsl:when>
    <xsl:when test="./@typ='p'">
      <xsl:apply-templates/>
    </xsl:when>
    <xsl:otherwise>
      <p><span class='Fehler'>Falscher Typ: Bitte melden Sie den Fehler:</span><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
-->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="key('key_kzinhalt_typ', 'f')" mode="dokumentanfang">
  <xsl:apply-templates/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="key('key_fzinhalt_typ', 'f')" mode="dokumentende">
  <xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>