<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version = "1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				      xmlns="http://www.w3.org/1999/xhtml"
				      xmlns:msxsl="urn:schemas-microsoft-com:xslt"
				      xmlns:bka="http://www.bka.gv.at">
<!--
 /////////////////////////////////////////////////////////////////
  Autor:       Hermann Anderl, Klaus Schipany
  Revision:    1.3
  Erstellt:    03.10.2003
  Modifiziert: 20.12.2003
 ///////////////////////////////////////////////////////////////// -->
<xsl:output method="xml" encoding="ISO-8859-1" indent="yes"/>

<!--
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ////
 //// Bei der Erstellung dieses Stylesheets wurden folgende Kriterien angewandt:
 ////
 //// 1.) Es wurde darauf geachtet folgende HTML-Elemente bzw. Attribute zu vermeiden, weil diese durch
 ////      CSS-Stylesheets abgedeckt werden knnen:
 ////      font, color, hr, h1, h2, h3, h4, h5, h6, sub, sup, i, b.
 ////
 //// 2.) Die Attribute align bzw. valign wurden nur in folgenden Situatonen verwendet:
 ////      a) innerhalb von Tabellen
 ////      b) in Situationen in denen eine im XML-Dokument angegebene Ausrichtung weiter gereicht werden muss.
 ////      An allen anderen Stellen erfolgt die Ausrichtung des Textes anhand der Angaben in den CSS-Stylesheets.
 ////
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// -->

<msxsl:script language="JScript" implements-prefix="bka">
   function replace(old) { return old.replace(/\./,"_"); }
</msxsl:script>

<!-- Distinct / Unique -->
<xsl:template match="table" mode="sort">
	<xsl:if test="@style">
		<xsl:text>
	      .</xsl:text><xsl:value-of select="generate-id(./@style)"/><xsl:text> { </xsl:text><xsl:value-of select="./@style"/><xsl:text> }</xsl:text>
	</xsl:if>
	<xsl:for-each select="tr/td">
  		<xsl:sort select="@width"/>
		<xsl:variable name="breite" select="@width"/>
		<!-- Prfen, ob dieser Wert zum 1. Mal genannt wurde -->
		<xsl:if test="not (preceding-sibling::td[@width=$breite]) and not (../preceding-sibling::tr/td[@width=$breite])">
			<xsl:text>
	      .W</xsl:text><xsl:value-of select="bka:replace(string($breite))"/><xsl:text> { width:</xsl:text><xsl:value-of select="$breite"/><xsl:text>;</xsl:text>
	      <xsl:if test="@style">
	      	<xsl:value-of select="@style"/>
	      </xsl:if>
	      <xsl:text>}</xsl:text>
    	</xsl:if>
  </xsl:for-each>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Keys
 ///////////////////////////////////////////////////////////////// -->
<xsl:key name="key_ueberschrift_typ" match="ueberschrift" use="@typ"/>
<xsl:key name="key_kzinhalt_typ" match="kzinhalt" use="@typ"/>
<xsl:key name="key_fzinhalt_typ" match="fzinhalt" use="@typ"/>
<!--
 /////////////////////////////////////////////////////////////////
 //// Aufbau des XHTML-Dokuments
 /////////////////////////////////////////////////////////////////-->
<xsl:template match="/">
  <xsl:element name="html">
    <!--<xsl:attribute name="xml:lang">de</xsl:attribute>-->
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ////////////////////////////////////////////////////////////////// -->
<xsl:template match="metadaten">
    <xsl:element name="head">
      <xsl:element name="title">eRecht XHTML 1.1 Dokument</xsl:element>
      <xsl:element name="style">
      <xsl:attribute name="type">text/css</xsl:attribute>
      <!-- Alle Breitenangaben (width) und generischen CSS-Angaben (style) durch CSS-classes ersetzen. -->
      <xsl:apply-templates select="//table" mode="sort"/>
		 <!-- In dieser Schleife werden alle Hhenangaben (height) in td-Elementen durch CSS-classes ersetzt. -->
      <xsl:for-each select="//td/@height">
        <xsl:sort/>
        <xsl:text>
        .H</xsl:text><xsl:value-of select="bka:replace(string(.))"/><xsl:text> { height: </xsl:text><xsl:value-of select="."/><xsl:text>;}</xsl:text>
      </xsl:for-each>
      <xsl:text>
        .W38 { width:38; }</xsl:text>
      <xsl:text>
        .W22 { width:22; }</xsl:text>
      <xsl:text>
        .W15 { width:15; }</xsl:text>
      <!-- Seitenrnder dynamisch setzen -->
      <xsl:variable name="layoutdaten" select = "//layoutdaten"></xsl:variable>
      <!-- Die Breiten sind in Points (pt) angegeben und werden so weitergereicht. -->
      <xsl:variable name="margt" select = "$layoutdaten/@margt"></xsl:variable>
      <xsl:variable name="margr" select = "$layoutdaten/@margr"></xsl:variable>
      <xsl:variable name="margb" select = "$layoutdaten/@margb"></xsl:variable>
      <xsl:variable name="margl" select = "$layoutdaten/@margl"></xsl:variable>
      <xsl:variable name="paperw" select = "$layoutdaten/@paperw"></xsl:variable>
      <xsl:if test="$layoutdaten/@margt | $layoutdaten/@margr | $layoutdaten/@margb | $layoutdaten/@margl">
        <xsl:text>
        .margins {</xsl:text>
        <xsl:if test="$layoutdaten/@margt">
          <xsl:value-of select="concat('margin-top:', $margt, 'pt;')"/>
        </xsl:if>
        <xsl:if test="$layoutdaten/@margr">
          <xsl:value-of select="concat('margin-right:', $margr, 'pt;')"/>
        </xsl:if>
        <xsl:if test="$layoutdaten/@margb">
          <xsl:value-of select="concat('margin-bottom:', $margb, 'pt;')"/>
        </xsl:if>
        <xsl:if test="$layoutdaten/@margl">
          <xsl:value-of select="concat('margin-left:', $margl, 'pt;')"/>
        </xsl:if>
        <xsl:text>}</xsl:text>        
      </xsl:if>
      <!-- Seitenbareite dynamisch setzen -->
      <xsl:if test="$layoutdaten/@paperw">
        <xsl:text>
        .paperw {</xsl:text>
        <xsl:value-of select="concat('width:', $paperw, 'px;')"/>
        <xsl:text>}</xsl:text>        
      </xsl:if>
/***************************************************************/
/* Autor:    Hermann Anderl                                    */
/* Erstellt: 1. Okt. 2003                                      */
/* Gendert: 19. Dez. 2003                                      */
/* Zweck:    Dieses Stylesheetfile wird fr den BKA-Konverter  */
/*           XML2XHTML11 verwendet.                            */
/***************************************************************/

/***************************************************************/
/* Allgemeine Angaben zum Anzeigen von Linien in Tabellen      */
/***************************************************************/

table.top
{
	border-top-style: solid;
	border-top-width: thin;
	border-color: black;
}

table.bottom
{
	border-bottom-style: solid;
	border-bottom-width: thin;
	border-color: black;
}

td.top
{
   border-top-style:solid;
   border-top-width:1pt;
}
td.right
{
   border-right-style:solid;
   border-right-width:1pt;
}
td.bottom
{
   border-bottom-style:solid;
   border-bottom-width:1pt;
}
td.left
{
   border-left-style:solid;
   border-left-width:1pt;
}

/***************************************************************/
/* Legistik-Standard-Formatvorlage                             */
/***************************************************************/

/* Formatvorlage: 00_LegStandard */
.LegStandard
{
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/***************************************************************/
/* Formatvorlagen fuer Absaetze                                */
/***************************************************************/

/* Formatvorlage: 01_Undefiniert */
p.Undefiniert
{
	margin-top:1.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color: red;
}

/* Formatvorlage: 02_BDGesBlatt */
p.BDGesBlatt
{
	margin-top:14.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:35.0pt;
	font-size:35.0pt;
	font-family:"Times New Roman";
	color:black;
	text-transform:uppercase;
	letter-spacing:1.3pt;
	font-weight:bold;
}

/* Formatvorlage: 03_RepOesterr */
p.RepOesterr
{
	margin-top:6.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	margin-bottom:12.0pt;
	text-align:center;
	line-height:20.0pt;
	border:none;
	padding:0cm;
	font-size:20.0pt;
	font-family:"Times New Roman";
	color:black;
	text-transform:uppercase;
	letter-spacing:1.0pt;
	font-weight:bold;
}

/* Formatvorlage: 04_AusgabeDaten */
p.AusgabeDaten
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:14.0pt;
	padding:0cm;
	font-size:12.0pt;
	font-family:"Times New Roman";
	color: black;
	font-weight:bold;
}

/* Formatvorlage: 05_Kurztitel */
/* Kurztitel in einer Spalte (wenn kein TAB vorhanden ist) */
p.Kurztitel1
{
	margin-top:2.0pt;
	margin-right: 0cm;
	margin-bottom:0cm;
	margin-left: 3.6cm;
	text-align:justify;
	text-indent: -3.6cm;
	border:none;
	padding:0cm;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Kurztitel in zwei Spalten (wenn ein TAB vorhanden ist) */
p.Kurztitel2
{
	margin-top:2.0pt;
	margin-right: 0cm;
	margin-bottom:0cm;
	margin-left: 0cm;
	text-align:justify;
	border:none;
	padding:0cm;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

span.Kurztitelbreite
{
	width: 3.4cm;
}

/* Formatvorlage: 09_Abstand */
p.Abstand
{
	margin:6.0pt;
	margin-bottom:6.0pt;
	line-height:10.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 10_Entwurf */
p.Entwurf
{
	margin-top:80.0pt;
	margin-right:0cm;
	margin-bottom:64.0pt;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	letter-spacing:1.3pt;
}

/* Formatvorlage: 11_Titel */
p.Titel
{
	margin-top:24.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:11.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

/* Formatvorlage: 12_PromKl_EinlSatz */	
p.PromKlEinlSatz
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	text-indent:19.85pt;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 18_Abbildung_oder_Objekt */
p.AbbildungoderObjekt
{
	margin-top:6.0pt;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 18_Abbildung_oder_Objekt */
p.AbbildungoderObjektL
{
	margin-top:6.0pt;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	text-align:left;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 18_Abbildung_oder_Objekt */
p.AbbildungoderObjektZ
{
	margin-top:6.0pt;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	text-align:center;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 18_Abbildung_oder_Objekt */
p.AbbildungoderObjektR
{
	margin-top:6.0pt;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	text-align:right;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 19_Beschriftung */
p.Beschriftung
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 19_Beschriftung */
p.BeschriftungL
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	line-height:11.0pt;
	text-align:left;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 19_Beschriftung */
p.BeschriftungZ
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	line-height:11.0pt;
	text-align:center;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 19_Beschriftung */
p.BeschriftungR
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	line-height:11.0pt;
	text-align:right;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 21_NovAo1 */
p.NovAo1
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
	font-style:italic;
}

/* Formatvorlage: 22_NovAo1 */
p.NovAo2
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	font-style:italic;
}

/* Formatvorlage: 23_Satz_(nach_Novao) */
p.SatznachNovao
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 30_InhaltUeberschrift */
p.InhaltUeberschrift
{
	margin-top:16.0pt;
	margin-right:0cm;
	margin-bottom:8.0pt;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

/* Formatvorlage: 31_InhaltSpalte */
p.InhaltSpalte
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:4.0pt;
	margin-left:0cm;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

/* Formatvorlage: 32_InhaltEintrag */
p.InhaltEintrag
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 41_UeberschrG1 */
p.UeberschrG1
{
	margin-top:16.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:11.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 42_UeberschrG1- */
p.UeberschrG1-
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:11.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 43_UeberschrG2 */
p.UeberschrG2
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:4.0pt;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:11.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 44_UeberschrArt */
p.UeberschrArt
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 45_UeberschrPara */
p.UeberschrPara
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 51_Abs */
p.Abs
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	text-indent:19.85pt;
/*	line-height:11.0pt; */
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 52_Ziffer_e1 */
p.ZifferE1
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 52_Ziffer_e2 */
p.ZifferE2
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 52_Ziffer_e3 */
p.ZifferE3
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 52_Ziffer_mit_Betrag */
p.ZifferMitBetrag
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	punctuation-wrap:simple;
	text-autospace:none;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 52aT_Ziffer_mit_Betrag_TGUE */
p.ZifferMitBetragTGUE
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	punctuation-wrap:simple;
	text-autospace:none;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 53_Litera_e1 */
p.LiteraE1
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 53_Litera_e2 */
p.LiteraE2
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 53_Litera_e3 */
p.LiteraE3
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 53_Litera_mit_Betrag */
p.LiteraMitBetrag
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	punctuation-wrap:simple;
	text-autospace:none;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 53aT_Litera_mit_Betrag_TGUE */
p.LiteraMitBetragTGUE
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	punctuation-wrap:simple;
	text-autospace:none;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54_Sublitera_e1 */
p.SubliteraE1
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54_Sublitera_e2 */
p.SubliteraE2
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54_Sublitera_e3 */
p.SubliteraE3
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54_Sublitera_mit_Betrag */
p.SubliteraMitBetrag
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	punctuation-wrap:simple;
	text-autospace:none;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54aT_Sublitera_mit_Betrag_TGUE */
p.SubliteraMitBetragTGUE
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	punctuation-wrap:simple;
	text-autospace:none;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54a_Strich_e1 */
p.StrichE1
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54a_Strich_e2 */
p.StrichE2
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54a_Strich_e3 */
p.StrichE3
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54a_Strich_e4 */
p.StrichE4
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54a_Strich_e5 */
p.StrichE5
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 54a_Strich_e6 */
p.StrichE6
{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 54a_Strich_e7 */
p.StrichE7
	{
	margin-top:2.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 55_SchlussteilAbs */
p.SchlussteilAbs
{
	margin:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 56_SchlussteilZiff */
p.SchlussteilZiff
{
	margin:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 57_SchlussteilLit */
p.SchlussteilLit
{
	margin:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 61_TabText */
p.TabText
{
	margin:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 61a_TabTextRechtsb */
p.TabTextRechtsb
{
	margin:0cm;
	text-align:right;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 61b_TabTextZentriert */
p.TabTextZentriert
{
	margin:0cm;
	text-align:center;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 61c_TabTextBlock */
p.TabTextBlock
{
	margin:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 62_Kopfzeile */
p.Kopfzeile
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color: #C0C0C0;
}

/* Formatvorlage: 63_Fuzeile */
p.Fusszeile
{
	margin-top:10.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:9.0pt;
	font-family:"Times New Roman";
	color: #C0C0C0;
}

/* Formatvorlage: 64_FN_Linie */
p.FNLinie
{
	margin-top:11.0pt;
	margin-right:13.0cm;
	margin-bottom:1.0pt;
	margin-left:0cm;
	line-height:11.0pt;
	padding:0cm;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	border-bottom-style: solid;
	border-bottom-color: Gray;
	border-bottom-width: 1px;
}

/* Formatvorlage: 65_FN_Text */
p.FNText
{
	margin:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:9.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 66_FN_Zeichen */
span.FNZeichen
{
	vertical-align:super;
}

/* Formatvorlage: 68_UnterschrL */
p.UnterschrL
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:left;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 69_UnterschrM */
p.UnterschrM
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 71_Anlagenbez */
p.Anlagenbez
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:right;
	line-height:11.0pt;
	font-size:11.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 81_ErlUeberschrZ */
p.ErlUeberschrZ
{
	margin-top:16.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:11.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 82_ErlUeberschrL */
p.ErlUeberschrL
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/* Formatvorlage: 83_ErlText */
p.ErlText
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
}

/* Formatvorlage: 85_ErlAufzaehlg - noch nicht fertig */
p.ErlAufzaehlg
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:19.85pt;
	text-align:justify;
	text-indent:-19.85pt;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
}

/* Formatvorlage: 89_TGUE_UeberschrSpalte*/
p.TGUEUeberschrSpalte
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:center;
	line-height:11.0pt;
	page-break-after:avoid;
	font-size:10.0pt;
	font-family:"Times New Roman";
	color:black;
	font-weight:bold;
}

/***************************************************************/
/* Formatvorlagen fuer Zeichenformatierung                     */
/***************************************************************/

/* Formatvorlage: 990_Fehler */
span.Fehler
{
	color: red;
}

/* Formatvorlage: 991_GldSymbol */
span.GldSymbol
{
	font-weight:bold;
}

/* Formatvorlage: 992_Normal */
span.Normal
{
	font-style: normal;
}

/* Formatvorlage: 993_Fett */
span.Fett
{
	font-weight:bold;
}

/* Formatvorlage: 994_Kursiv */
span.Kursiv
{
	font-style:italic;
}

/* Formatvorlage: 995_Unterstrichen */
span.Unterstrichen
{
	text-decoration:underline;
}

/* Formatvorlage: 996_Gesperrt */
span.Gesperrt
{
	letter-spacing:1.3pt;
}

/* Formatvorlage: 997_Hoch */
span.Hoch
{
	line-height: 60%;
	font-size: 60%;
	vertical-align:super;
}

/* Formatvorlage: 998_Tief */
span.Tief
{
	vertical-align:sub;
}

/* Formatvorlage: 999_Fett_und_Kursiv */
span.FettundKursiv
{
	font-weight:bold;
	font-style:italic;
}

/* Standardtabschrittweite aus Word */
span.Standardtabulator
{
	width:35.45pt;
}

/***************************************************************/
/* Formatvorlagen der Parlamentsdirektion                      */
/***************************************************************/

p.PDAllonge, li.PDAllonge, div.PDAllonge
{
	margin-top:14.0pt;
	margin-right:0cm;
	margin-bottom:10.0pt;
	margin-left:0cm;
	text-align:center;
	font-size:14.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
}

p.PDAllongeB, li.PDAllongeB, div.PDAllongeB
{
	margin-top:14.0pt;
	margin-right:0cm;
	margin-bottom:10.0pt;
	margin-left:0cm;
	text-align:justify;
	font-size:14.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
}

p.PDAllongeL, li.PDAllongeL, div.PDAllongeL
{
	margin-top:14.0pt;
	margin-right:0cm;
	margin-bottom:10.0pt;
	margin-left:0cm;
	font-size:14.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
}

p.PDAntragsformel, li.PDAntragsformel, div.PDAntragsformel
{
	margin-top:14.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
}

p.PDDatum, li.PDDatum, div.PDDatum
{
	margin-top:14.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
}

p.PDEntschliessung, li.PDEntschliessung, div.PDEntschliessung
{
	margin-top:8.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:11.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
	font-weight:bold;
}

p.PDK1, li.PDK1, div.PDK1
{
	margin:0cm;
	text-align:center;
	border:none;
	padding:0cm;
	font-size:12.0pt;
	font-family:"Times New Roman";
	letter-spacing:-.4pt;
	font-weight:bold;
}

p.PDK1Anlage, li.PDK1Anlage, div.PDK1Anlage
{
	margin:0cm;
	text-align:right;
	font-size:12.0pt;
	font-family:"Times New Roman";
	letter-spacing:-.4pt;
	font-weight:bold;
}

p.PDK1Ausg, li.PDK1Ausg, div.PDK1Ausg
{
	margin-top:62.9pt;
	margin-right:0cm;
	margin-bottom:27.0pt;
	margin-left:0cm;
	font-size:11.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

p.PDK2, li.PDK2, div.PDK2
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:11.35pt;
	margin-left:0cm;
	font-size:22.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

p.PDK3, li.PDK3, div.PDK3
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:20.0pt;
	margin-left:0cm;
	font-size:18.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

p.PDK4, li.PDK4, div.PDK4
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:6.0pt;
	margin-left:0cm;
	font-size:13.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

p.PDKopfzeile, li.PDKopfzeile, div.PDKopfzeile
{
	margin-top:4.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
}

p.PDU1, li.PDU1, div.PDU1
{
	margin-top:22.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:10.0pt;
	font-family:"Times New Roman";
	font-weight:bold;
}

p.PDU2, li.PDU2, div.PDU2
{
	margin-top:5.0pt;
	margin-right:0cm;
	margin-bottom:0cm;
	margin-left:0cm;
	line-height:11.0pt;
	font-size:9.0pt;
	font-family:"Times New Roman";
}

p.PDVorlage, li.PDVorlage, div.PDVorlage
{
	margin-top:0cm;
	margin-right:0cm;
	margin-bottom:10.0pt;
	margin-left:0cm;
	text-align:justify;
	line-height:11.0pt;
	font-size:11.0pt;
	font-family:"Times New Roman";
	layout-grid-mode:line;
	font-weight:bold;
}
	        <!--@import "j:\\XML2XHTML32\\eRechtXML2XHTML11.css";--> <!--DEBUG only-->
      </xsl:element>
    </xsl:element>
</xsl:template>
<!-- ////////////////////////////////////////////////////////////////// -->
<xsl:template match="nutzdaten">
  <xsl:element name="body">
    <xsl:attribute name="class">LegStandard</xsl:attribute>
    <xsl:variable name="layoutdaten" select = "//layoutdaten"></xsl:variable>
    <xsl:if test="$layoutdaten/@margt | $layoutdaten/@margr | $layoutdaten/@margb | $layoutdaten/@margl">
      <xsl:attribute name="class">
        <xsl:text>margins</xsl:text>
      </xsl:attribute>
    </xsl:if>
    <xsl:element name="table">
      <xsl:if test="$layoutdaten/@paperw">
        <xsl:attribute name="class">paperw</xsl:attribute>
      </xsl:if>
      <xsl:element name="tr">
        <xsl:if test="$layoutdaten/@paperw">
          <xsl:attribute name="class">paperw</xsl:attribute>
          <!-- In XHTML1.1 ist das width-Attribut nicht beim tr-Element erlaubt. -->
        </xsl:if>      
        <xsl:element name="td">
          <xsl:if test="$layoutdaten/@paperw">
            <xsl:attribute name="class">paperw</xsl:attribute>
            <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
          </xsl:if>
          <xsl:apply-templates select="key('key_kzinhalt_typ', 'f')[1]" mode="dokumentanfang"/>
          <xsl:apply-templates/>
          <xsl:apply-templates select="//fnen" mode="dokumentende"/>
          <xsl:apply-templates select="key('key_fzinhalt_typ', 'f')[1]" mode="dokumentende"/>
          <!--      <xsl:apply-templates select="//fzinhalt" mode="dokumentende"/> -->
        </xsl:element>
      </xsl:element>
    </xsl:element>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Ausgabedaten
 ///////////////////////////////////////////////////////////////// -->
<xsl:template match="ausgabe">
  <xsl:element name="table">
    <xsl:attribute name="width">100%</xsl:attribute>
    <xsl:attribute name="class">top bottom</xsl:attribute>
<!--  <xsl:attribute name="border">1</xsl:attribute> -->
    <xsl:element name="tr">
      <xsl:apply-templates mode="erzeuge_ausgabe"/>
    </xsl:element>
  </xsl:element>
</xsl:template>

<xsl:template match="adtext" mode="erzeuge_ausgabe">
  <xsl:element name="td">
    <xsl:attribute name="align">left</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class">AusgabeDaten</xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:element>
</xsl:template>

<xsl:template match="addat" mode="erzeuge_ausgabe">
  <xsl:element name="td">
    <xsl:attribute name="align">center</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class">AusgabeDaten</xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:element>
</xsl:template>

<xsl:template match="adid" mode="erzeuge_ausgabe">
  <xsl:element name="td">
    <xsl:attribute name="align">right</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class">AusgabeDaten</xsl:attribute>
        <xsl:apply-templates/>
      </xsl:element>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Kurztitel
 ///////////////////////////////////////////////////////////////// -->
<xsl:template match="*" mode="erzeuge_zeilen"></xsl:template><!-- nichts tun -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="key('key_ueberschrift_typ', 'kurztitel')" mode="erzeuge_zeilen">
      <xsl:element name="tr">
        <xsl:if test="tab[1]">
          <xsl:element name="td">
            <xsl:attribute name="align">left</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class">Kurztitel2</xsl:attribute>
              <xsl:element name="span">
                <xsl:attribute name="class">Kurztitelbreite</xsl:attribute>
                <!-- Verarbeite nun alles was vor dem 1. Tabulator kommt. -->
                <!-- tab[1]/preceding-sibling::text() bewirkt die Verarbeitung aller Textknoten vor dem 1. Tab. -->
                <!-- tab[1]/preceding-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
                <xsl:for-each select="tab[1]/preceding-sibling::text() | tab[1]/preceding-sibling::*">
                  <xsl:apply-templates select="."/>
                </xsl:for-each>
              </xsl:element>
            </xsl:element>
          </xsl:element>
          <xsl:element name="td">
            <xsl:attribute name="align">left</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class">Kurztitel2</xsl:attribute>
            <!-- Verarbeite nun den Rest ab dem 1. Tabulator. -->
            <!-- tab[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem 1. Tab. -->
            <!-- tab[1]/following-sibling::* bewirkt die Verarbeitung der restlichen Tabulatoren und enthaltener Subknoten. -->
            <xsl:for-each select="tab[1]/following-sibling::text() | tab[1]/following-sibling::*">
              <xsl:apply-templates select="."/>
            </xsl:for-each>
            </xsl:element>
          </xsl:element>
        </xsl:if>
        <xsl:if test="not(tab[1])">
          <!-- Da es keinen Tabulator gibt, wird nur eine Spalte erzeugt. -->
          <xsl:element name="td">
            <xsl:attribute name="align">left</xsl:attribute>
            <xsl:attribute name="valign">top</xsl:attribute>
            <xsl:attribute name="colspan">2</xsl:attribute>
            <xsl:element name="p">
              <xsl:attribute name="class">Kurztitel1</xsl:attribute>
                <xsl:apply-templates/>
            </xsl:element>
          </xsl:element>
        </xsl:if>
      </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Inhaltsverzeichnis, HTML-Tabellen ////
 ///////////////////////////////////////////////////////////////// -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="inhaltsvz ">
  <xsl:choose >
    <xsl:when test="./@typ='ueberschrift'">
    	 <xsl:element name="p">
    	 	<xsl:attribute name="class">InhaltUeberschrift</xsl:attribute>
			<xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='spalte'">
      <xsl:element name="p">
        <xsl:attribute name="class">InhaltSpalte</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='eintrag'">
      <xsl:element name="p">
        <xsl:attribute name="class">InhaltEintrag</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element> 
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="table">
    <xsl:element name="table">
      <xsl:apply-templates select="./@*"/>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="tr">
    <xsl:element name="tr">
      <xsl:apply-templates select="./@*"/>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="td">
    <xsl:element name="td">
      <xsl:apply-templates select="./@*"/>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@border">
  <xsl:attribute name="border"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@cellspacing">
  <xsl:attribute name="cellspacing"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@cellpadding">
  <xsl:attribute name="cellpadding"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@colspan">
  <xsl:attribute name="colspan"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@rowspan">
  <xsl:attribute name="rowspan"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@width">
  <xsl:choose >
    <xsl:when test="ancestor::td | ancestor::tr">
      <xsl:attribute name="class"><xsl:value-of select = "string('W')"/><xsl:value-of select = "bka:replace(string(.))" /></xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <!-- Das width-Attribut wird einfach weiter gereicht. -->
      <xsl:attribute name="width"><xsl:value-of select = "." /></xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@height">
  <xsl:choose >
    <xsl:when test="ancestor::td | ancestor::tr">
      <xsl:attribute name="class"><xsl:value-of select = "string('H')"/><xsl:value-of select = "bka:replace(string(.))" /></xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <!-- Das height-Attribut wird einfach weiter gereicht. -->
      <xsl:attribute name="height"><xsl:value-of select = "." /></xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@align">
  <xsl:attribute name="align"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@valign">
  <xsl:attribute name="valign"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@style">
  <xsl:choose >
    <xsl:when test="ancestor::td | ancestor::tr">
      <xsl:if test="not(../@width)">
      	<xsl:attribute name="class"><xsl:value-of select = "generate-id(.)"/></xsl:attribute>
      </xsl:if>
    </xsl:when>
    <xsl:when test="ancestor::table">
    	<xsl:attribute name="class"><xsl:value-of select = "generate-id(.)"/></xsl:attribute>
    </xsl:when>
    <xsl:otherwise>
      <!-- Das style-Attribut wird einfach weiter gereicht. -->
      <xsl:attribute name="style"><xsl:value-of select = "." /></xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@class">
  <xsl:attribute name="class"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@h-start"><!-- nichts tun -->
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@h-xval"><!-- nichts tun -->
</xsl:template>

<xsl:template name="checkForEmptyCell">
  <xsl:if test="ancestor::table">
    <xsl:if test=". = ''"><xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/></xsl:if>
  </xsl:if>
  <xsl:apply-templates/>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Ueberschriften
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="ueberschrift">
  <xsl:choose >
    <xsl:when test="./@typ='bdgesblatt'">
      <xsl:element name="p">
        <xsl:attribute name="class">BDGesBlatt</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
        </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='repoesterr'">
      <xsl:element name="p">
        <xsl:attribute name="class">RepOesterr</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='entwurf'">
      <xsl:element name="p">
        <xsl:attribute name="class">Entwurf</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='kurztitel'">
      <xsl:if test="not(name(preceding-sibling::*[1]) = 'ueberschrift')">
      <xsl:element name="table">
        <xsl:attribute name="width">100%</xsl:attribute>
        <xsl:attribute name="class">bottom</xsl:attribute>
<!--        <xsl:attribute name="parent"><xsl:value-of select="name(parent::*)"/></xsl:attribute>
        <xsl:attribute name="preceding"><xsl:value-of select="name(preceding::*)"/></xsl:attribute>
        <xsl:attribute name="preceding-sibling"><xsl:value-of select="name(preceding-sibling::*)"/></xsl:attribute>
        <xsl:attribute name="preceding-sibling-typ"><xsl:value-of select="preceding-sibling::*/@typ"/></xsl:attribute>
        <xsl:attribute name="count-preceding-sibling"><xsl:value-of select="count(preceding-sibling::*)"/></xsl:attribute>
        <xsl:attribute name="count-preceding"><xsl:value-of select="count(preceding::*)"/></xsl:attribute>
        <xsl:attribute name="yyy-sibling-typ"><xsl:value-of select="name(preceding-sibling::*[1])"/></xsl:attribute>
        <xsl:attribute name="zzz-sibling-typ"><xsl:value-of select="name(preceding::*[1])"/></xsl:attribute> -->
        <xsl:apply-templates select="../ueberschrift" mode="erzeuge_zeilen"/>
      </xsl:element>
      </xsl:if>
    </xsl:when>
    <xsl:when test="./@typ='titel'">
      <xsl:element name="p">
        <xsl:attribute name="class">Titel</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='g1'">
      <xsl:element name="p">
        <xsl:attribute name="class">UeberschrG1</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='g2'">
      <xsl:element name="p">
        <xsl:attribute name="class">UeberschrG2</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='g1min'">
      <xsl:element name="p">
        <xsl:attribute name="class">UeberschrG1-</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='art'">
      <xsl:element name="p">
        <xsl:attribute name="class">UeberschrArt</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='para'">
      <xsl:element name="p">
        <xsl:attribute name="class">UeberschrPara</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='anlage'">
      <xsl:element name="p">
        <xsl:attribute name="class">Anlagenbez</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='erlz'">
      <xsl:element name="p">
        <xsl:attribute name="class">ErlUeberschrZ</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='erll'">
      <xsl:element name="p">
        <xsl:attribute name="class">ErlUeberschrL</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='tgue'">
      <xsl:element name="p">
        <xsl:attribute name="class">TGUEUeberschrSpalte</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Absaetze
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="absatz">
  <xsl:choose >
    <xsl:when test="./@typ='undef'">
      <xsl:element name="p">
        <xsl:attribute name="class">Undefiniert</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='promkleinlsatz'">
      <xsl:element name="p">
        <xsl:attribute name="class">PromKlEinlSatz</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='abs'">
      <xsl:element name="p">
        <xsl:attribute name="class">Abs</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='abbobj'">
      <xsl:element name="p">
        <xsl:choose >
          <xsl:when test="./@halign='left'">
            <xsl:attribute name="class">AbbildungoderObjektL</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:when>
          <xsl:when test="./@halign='center'">
            <xsl:attribute name="class">AbbildungoderObjektZ</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:when>
          <xsl:when test="./@halign='right'">
            <xsl:attribute name="class">AbbildungoderObjektR</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="class">AbbildungoderObjekt</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='novao1'">
      <xsl:element name="p">
        <xsl:attribute name="class">NovAo1</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='novao2'">
      <xsl:element name="p">
        <xsl:attribute name="class">NovAo2</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='satz'">
      <xsl:element name="p">
        <xsl:attribute name="class">SatznachNovao</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='tabtext'">
      <xsl:element name="p">
        <xsl:attribute name="class">TabText</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='tabtextr'">
      <xsl:element name="p">
        <xsl:attribute name="class">TabTextRechtsb</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='tabtextz'">
      <xsl:element name="p">
        <xsl:attribute name="class">TabTextZentriert</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='tabtextb'">
      <xsl:element name="p">
        <xsl:attribute name="class">TabTextBlock</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='erltext'">
      <xsl:element name="p">
        <xsl:attribute name="class">ErlText</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='kz'">
      <xsl:element name="p">
        <xsl:attribute name="class">Kopfzeile</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='fz'">
      <xsl:element name="p">
        <xsl:attribute name="class">Fusszeile</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="abstand">
  <xsl:element name="p">
    <xsl:attribute name="class">Abstand</xsl:attribute>
    <xsl:call-template name="checkForEmptyCell"/>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Normale Liste / Aufzaehlung
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="liste">
    <xsl:element name="table">
      <xsl:attribute name="width">100%</xsl:attribute>
      <xsl:apply-templates/>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="ziffernliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">ZifferE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">ZifferE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">ZifferE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falsche Ebene: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="literaliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">LiteraE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">LiteraE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">LiteraE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falsche Ebene: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="subliteraliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">SubliteraE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">SubliteraE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">SubliteraE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falsche Ebene: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="strichliste">
  <xsl:choose >
    <xsl:when test="./@ebene='1'">
      <xsl:apply-templates mode="erzeuge_liste_ebene1">
        <xsl:with-param name="classname">StrichE1</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='2'">
      <xsl:apply-templates mode="erzeuge_liste_ebene2">
        <xsl:with-param name="classname">StrichE2</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='3'">
      <xsl:apply-templates mode="erzeuge_liste_ebene3">
        <xsl:with-param name="classname">StrichE3</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@ebene='4'">
      <xsl:apply-templates mode="erzeuge_liste_ebene4">
        <xsl:with-param name="classname">StrichE4</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falsche Ebene: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene1">
  <xsl:param name = "classname"/>
    <xsl:element name="tr">
      <xsl:element name="td">
        <xsl:attribute name="class">W38</xsl:attribute>
        <!-- In XHTML1.1: width-Attribut bei td-Element nicht erlaubt. -->
        <xsl:attribute name="align">right</xsl:attribute>
        <xsl:attribute name="valign">top</xsl:attribute>
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:apply-templates select="symbol[1]"/>
        </xsl:element>
      </xsl:element>
      <xsl:element name="td">
        <xsl:attribute name="align">justify</xsl:attribute>
        <xsl:attribute name="colspan">7</xsl:attribute>
        <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </xsl:element>
      </xsl:element>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene2">
  <xsl:param name = "classname"/>
    <xsl:element name="tr">
      <xsl:element name="td"/>
      <xsl:element name="td">
        <xsl:attribute name="class">W15</xsl:attribute>
        <!-- In XHTML1.1: width-Attribut bei td-Element nicht erlaubt. -->
        <xsl:attribute name="align">right</xsl:attribute>
        <xsl:attribute name="valign">top</xsl:attribute>
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:apply-templates select="symbol[1]"/>
        </xsl:element>
      </xsl:element>
      <xsl:element name="td">
        <xsl:attribute name="align">justify</xsl:attribute>
        <xsl:attribute name="colspan">6</xsl:attribute>
        <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </xsl:element>
      </xsl:element>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene3">
  <xsl:param name = "classname"/>
    <xsl:element name="tr">
      <xsl:element name="td"/>
      <xsl:element name="td"/>
      <xsl:element name="td">
        <xsl:attribute name="class">W22</xsl:attribute>
        <!-- In XHTML1.1: width-Attribut bei td-Element nicht erlaubt. -->
        <xsl:attribute name="align">right</xsl:attribute>
        <xsl:attribute name="valign">top</xsl:attribute>
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:apply-templates select="symbol[1]"/>
        </xsl:element>
      </xsl:element>
      <xsl:element name="td">
        <xsl:attribute name="align">justify</xsl:attribute>
        <xsl:attribute name="colspan">5</xsl:attribute>
        <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </xsl:element>
      </xsl:element>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_liste_ebene4">
  <xsl:param name = "classname"/>
    <xsl:element name="tr">
      <xsl:element name="td"/>
      <xsl:element name="td"/>
      <xsl:element name="td"/>
      <xsl:element name="td">
        <xsl:attribute name="class">W22</xsl:attribute>
        <!-- In XHTML1.1: width-Attribut bei td-Element nicht erlaubt. -->
        <xsl:attribute name="align">right</xsl:attribute>
        <xsl:attribute name="valign">top</xsl:attribute>
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:apply-templates select="symbol[1]"/>
        </xsl:element>
      </xsl:element>
      <xsl:element name="td">
        <xsl:attribute name="align">justify</xsl:attribute>
        <xsl:attribute name="colspan">4</xsl:attribute>
        <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
        <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
        <xsl:element name="p">
          <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
          <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
            <xsl:apply-templates select="."/>
          </xsl:for-each>
        </xsl:element>
      </xsl:element>
    </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="schluss">
  <xsl:choose >
    <xsl:when test="./@typ='Abs'">
      <xsl:element name="tr">
        <xsl:element name="td">
          <xsl:attribute name="align">justify</xsl:attribute>
          <xsl:attribute name="colspan">8</xsl:attribute>
          <xsl:element name="p">
            <xsl:attribute name="class">SchlussteilAbs</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:element>
        </xsl:element>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='Ziff'">
      <xsl:element name="tr">
        <xsl:element name="td">
          <xsl:attribute name="class">W38</xsl:attribute><!-- wie Ebene 1 -->
          <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
          <!--xsl:attribute name="width">38</xsl:attribute--><!-- wie Ebene 1 -->
        </xsl:element>
        <xsl:element name="td">
          <xsl:attribute name="align">justify</xsl:attribute>
          <xsl:attribute name="colspan">7</xsl:attribute>
          <xsl:element name="p">
            <xsl:attribute name="class">SchlussteilZiff</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:element>
        </xsl:element>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='Lit'">
      <xsl:element name="tr">
        <xsl:element name="td"/>
        <xsl:element name="td">
          <xsl:attribute name="class">W15</xsl:attribute><!-- wie Ebene 2 -->
          <!-- In XHTML1.1 ist das width-Attribut nicht beim td-Element erlaubt. -->
          <!--xsl:attribute name="width">15</xsl:attribute--><!-- wie Ebene 2 -->
        </xsl:element>
        <xsl:element name="td">
          <xsl:attribute name="align">justify</xsl:attribute>
          <xsl:attribute name="colspan">6</xsl:attribute>
          <xsl:element name="p">
            <xsl:attribute name="class">SchlussteilLit</xsl:attribute>
            <xsl:call-template name="checkForEmptyCell"/>
          </xsl:element>
        </xsl:element>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Liste mit Betrag
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="betragliste">
  <xsl:choose >
    <xsl:when test="./@typ='ziffer'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene1">
        <xsl:with-param name="classname">ZifferMitBetrag</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='litera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene2">
        <xsl:with-param name="classname">LiteraMitBetrag</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='sublitera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene3">
        <xsl:with-param name="classname">SubliteraMitBetrag</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="betraglistetgue">
  <xsl:choose >
    <xsl:when test="./@typ='ziffer'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene1">
        <xsl:with-param name="classname">ZifferMitBetragTGUE</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='litera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene2">
        <xsl:with-param name="classname">LiteraMitBetragTGUE</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="./@typ='sublitera'">
      <xsl:apply-templates mode="erzeuge_betragliste_ebene3">
        <xsl:with-param name="classname">SubliteraMitBetragTGUE</xsl:with-param>
      </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_betragliste_ebene1">
  <xsl:param name = "classname"/>
  <xsl:element name="tr">
    <xsl:element name="td">
      <xsl:attribute name="align">right</xsl:attribute>
      <xsl:attribute name="valign">top</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
        <xsl:apply-templates select="symbol[1]"/>
      </xsl:element>
    </xsl:element>
    <xsl:element name="td">
      <xsl:attribute name="align">justify</xsl:attribute>
      <xsl:attribute name="colspan">5</xsl:attribute>
      <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
      <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
      <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
      <xsl:element name="p">
        <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
        <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
          <xsl:if test="name() = 'tab'">
            <xsl:value-of select="string('&lt;/p&gt;&lt;/td&gt;&lt;td&gt;&lt;p class=&quot;')" disable-output-escaping="yes"/>
            <xsl:value-of select = "$classname"/><xsl:value-of select="string('&quot;&gt;')" disable-output-escaping="yes"/>
          </xsl:if>
          <xsl:if test="name() != 'tab'">
            <xsl:apply-templates select="."/>
          </xsl:if>
        </xsl:for-each>
      </xsl:element>
    </xsl:element>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_betragliste_ebene2">
  <xsl:param name = "classname"/>
  <xsl:element name="tr">
    <xsl:element name="td"/>
    <xsl:element name="td">
      <xsl:attribute name="align">right</xsl:attribute>
      <xsl:attribute name="valign">top</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
        <xsl:apply-templates select="symbol[1]"/>
      </xsl:element>
    </xsl:element>
    <xsl:element name="td">
      <xsl:attribute name="align">justify</xsl:attribute>
      <xsl:attribute name="colspan">4</xsl:attribute>
      <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
      <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
      <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
      <xsl:element name="p">
        <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
        <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
          <xsl:if test="name() = 'tab'">
            <xsl:value-of select="string('&lt;/p&gt;&lt;/td&gt;&lt;td&gt;&lt;p class=&quot;')" disable-output-escaping="yes"/>
            <xsl:value-of select = "$classname"/><xsl:value-of select="string('&quot;&gt;')" disable-output-escaping="yes"/>
          </xsl:if>
          <xsl:if test="name() != 'tab'">
            <xsl:apply-templates select="."/>
          </xsl:if>
        </xsl:for-each>
      </xsl:element>
    </xsl:element>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="listelem" mode="erzeuge_betragliste_ebene3">
  <xsl:param name = "classname"/>
  <xsl:element name="tr">
    <xsl:element name="td"/>
    <xsl:element name="td"/>
    <xsl:element name="td">
      <xsl:attribute name="align">right</xsl:attribute>
      <xsl:attribute name="valign">top</xsl:attribute>
      <xsl:element name="p">
        <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
        <xsl:apply-templates select="symbol[1]"/>
      </xsl:element>
    </xsl:element>
    <xsl:element name="td">
      <xsl:attribute name="align">justify</xsl:attribute>
      <xsl:attribute name="colspan">3</xsl:attribute>
      <!-- Verarbeite nun den Rest ab dem Symbolknoten. -->
      <!-- symbol[1]/following-sibling::text() bewirkt die Verarbeitung aller Textknoten nach dem Symbolknoten. -->
      <!-- symbol[1]/following-sibling::* bewirkt die Verarbeitung der enthaltenen Subknoten. -->
      <xsl:element name="p">
        <xsl:attribute name="class"><xsl:value-of select = "$classname"/></xsl:attribute>
        <xsl:for-each select="symbol[1]/following-sibling::text() | symbol[1]/following-sibling::*">
          <xsl:if test="name() = 'tab'">
            <xsl:value-of select="string('&lt;/p&gt;&lt;/td&gt;&lt;td&gt;&lt;p class=&quot;')" disable-output-escaping="yes"/>
            <xsl:value-of select = "$classname"/><xsl:value-of select="string('&quot;&gt;')" disable-output-escaping="yes"/>
          </xsl:if>
          <xsl:if test="name() != 'tab'">
            <xsl:apply-templates select="."/>
          </xsl:if>
        </xsl:for-each>
      </xsl:element>
    </xsl:element>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Unterschrift
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="unterschrift">
  <xsl:choose >
    <xsl:when test="./@typ='links'">
      <xsl:element name="p">
        <xsl:attribute name="class">UnterschrL</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='mitte'">
      <xsl:element name="p">
        <xsl:attribute name="class">UnterschrM</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='rechts'">
      <xsl:element name="p">
        <xsl:attribute name="class">UnterschrR</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>    
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Zeichenformatierung
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="error">
  <xsl:element name="span">
    <xsl:attribute name="class">Fehler</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="gldsym">
  <xsl:element name="span">
    <xsl:attribute name="class">GldSymbol</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="n">
  <xsl:element name="span">
    <xsl:attribute name="class">Normal</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="f | b">
  <xsl:element name="span">
    <xsl:attribute name="class">Fett</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="k | i">
  <xsl:element name="span">
    <xsl:attribute name="class">Kursiv</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="u">
  <xsl:element name="span">
    <xsl:attribute name="class">Unterstrichen</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="gs">
  <xsl:element name="span">
    <xsl:attribute name="class">Gesperrt</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="h | super">
  <xsl:element name="span">
    <xsl:attribute name="class">Hoch</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="t | sub">
  <xsl:element name="span">
    <xsl:attribute name="class">Tief</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="fk">
  <xsl:element name="span">
    <xsl:attribute name="class">FettundKursiv</xsl:attribute>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Sonderzeichen
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="nbsp">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// doppeltes Anfhrungszeichen unten -->
<xsl:template match="bdquo">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#34;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// doppeltes Anfhrungszeichen oben -->
<xsl:template match="ldquo">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#34;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// Gedankenstrich -->
<xsl:template match="kidea">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#45;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// Bindestrich -->
<xsl:template match="gdash">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;#45;')"/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// Silbentrennzeichen -->
<xsl:template match="bdash"><!-- nichts tun -->
</xsl:template>

<xsl:template match="tab">
  <!-- Da weder in HTML noch in CSS2 Tabulatoren moeglich sind, wird ein Tabulator durch ein Blank ersetzt, das in span eingeschlossen ist. -->
  <xsl:element name="span">
    <xsl:attribute name="class">Standardtabulator</xsl:attribute>
    <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="euro">
  <xsl:value-of disable-output-escaping="yes" select="string('&amp;euro;')"/>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Verweise
 ///////////////////////////////////////////////////////////////// -->

<xsl:template match="wwwlink">
  <xsl:element name="a">
    <xsl:apply-templates select="./@*"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="@url">
  <xsl:attribute name="href"><xsl:value-of select = "." /></xsl:attribute>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////////////////
 //// Eingebettete base64-codierte Binrdaten
 /////////////////////////////////////////////////////////////////////////////

 Alle Binrdateien werden in ein Unterverzeichnis ausgelagert. 
 Das binary-Element mu ein ref-Attribut besitzen, das den relativen
 Dateinamen der ausgelagerten Datei enthlt. -->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="binary">
  <xsl:element name="img">
    <xsl:if test="./@ref">
      <xsl:if test="./@ref = ''">
        <xsl:attribute name="src"><xsl:value-of select = "string('.\unknown.')" /><xsl:value-of select = "./@datatype" /></xsl:attribute>
      </xsl:if>
      <xsl:if test="not(./@ref = '')">
        <xsl:attribute name="src"><xsl:value-of select = "./@ref" /></xsl:attribute>
      </xsl:if>
    </xsl:if>
    <xsl:if test="not(./@ref)">
      <xsl:attribute name="src"><xsl:value-of select = "string('.\unknown.')" /><xsl:value-of select = "./@datatype" /></xsl:attribute>
    </xsl:if>
    <xsl:attribute name="alt"><xsl:value-of select = "./@alt" /></xsl:attribute>
  </xsl:element>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Beschriftung zu Grafiken
 ///////////////////////////////////////////////////////////////// -->

<!-- Da beim p-Element in XHTML kein align-Attribut erlaubt ist, wird mit mehreren CSS-Klassen fuer die Beschriftung gearbeitet. -->
<xsl:template match="beschr">
  <xsl:choose >
    <xsl:when test="./@typ='links'">
      <xsl:element name="p">
        <xsl:attribute name="class">BeschriftungL</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='mitte'">
      <xsl:element name="p">
        <xsl:attribute name="class">BeschriftungZ</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='rechts'">
      <xsl:element name="p">
        <xsl:attribute name="class">BeschriftungR</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:attribute name="class">Beschriftung</xsl:attribute>
        <xsl:call-template name="checkForEmptyCell"/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Fu- und Endnoten
 ///////////////////////////////////////////////////////////////// -->

<!-- Fuzeilen sollen erst am Ende verarbeitet werden -->
<xsl:template match="fnen"><!-- nichts tun -->
</xsl:template>

<xsl:template match="fnen" mode="dokumentende">
  <xsl:apply-templates/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<!-- In XHTML1.1: Statt dem Attribut "name" wird jetzt "id" verwendet. -->
<xsl:template match="fnzeichen">
  <xsl:choose >
    <xsl:when test="./@typ='f'">
      <xsl:element name="a">
        <xsl:attribute name="href"><xsl:value-of select = "string('#FN')" /><xsl:value-of select = "." /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select = "string('FNREF')" /><xsl:value-of select = "." /></xsl:attribute>
        <xsl:element name="span">
          <xsl:attribute name="class">FNText</xsl:attribute><!-- kein FNZeichen! -->
          <xsl:value-of select = "string('[')" />
          <xsl:apply-templates/>
          <xsl:value-of select = "string(']')" />
        </xsl:element>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='e'">
      <xsl:element name="a">
        <xsl:attribute name="href"><xsl:value-of select = "string('#EN')" /><xsl:value-of select = "." /></xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select = "string('ENREF')" /><xsl:value-of select = "." /></xsl:attribute>
        <xsl:element name="span">
          <xsl:attribute name="class">FNText</xsl:attribute><!-- kein FNZeichen! -->
          <xsl:value-of select = "string('[')" />
          <xsl:apply-templates/>
          <xsl:value-of select = "string(']')" />
        </xsl:element>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<!-- In XHTML1.1: Statt dem Attribut "name" wird jetzt "id" verwendet. -->
<xsl:template match="fntext">
  <xsl:choose >
    <xsl:when test="./@typ='f'">
      <xsl:if test="./@nr = 1">
        <xsl:element name="p">
          <xsl:attribute name="class">FNLinie</xsl:attribute>
        </xsl:element>
      </xsl:if>
      <xsl:element name="p">
        <xsl:attribute name="class">FNText</xsl:attribute>
        <xsl:element name="a">
          <xsl:attribute name="href"><xsl:value-of select = "string('#FNREF')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <xsl:attribute name="id"><xsl:value-of select = "string('FN')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <xsl:element name="span">
            <xsl:attribute name="class">FNText</xsl:attribute><!-- unten kein FNZeichen! -->
            <xsl:value-of select = "string('[')" />
            <xsl:value-of select = "./@nr" />
            <xsl:value-of select = "string(']')" />
          </xsl:element>
        </xsl:element>
        <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:when>
    <xsl:when test="./@typ='e'">
      <xsl:if test="./@nr = 1">
        <xsl:element name="p">
          <xsl:attribute name="class">FNLinie</xsl:attribute>
        </xsl:element>
      </xsl:if>
      <xsl:element name="p">
        <xsl:attribute name="class">FNText</xsl:attribute>
        <xsl:element name="a">
          <xsl:attribute name="href"><xsl:value-of select = "string('#ENREF')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <xsl:attribute name="id"><xsl:value-of select = "string('EN')" /><xsl:value-of select = "./@nr" /></xsl:attribute>
          <xsl:element name="span">
            <xsl:attribute name="class">FNText</xsl:attribute><!-- unten kein FNZeichen! -->
            <xsl:value-of select = "string('[')" />
            <xsl:value-of select = "./@nr" />
            <xsl:value-of select = "string(']')" />
          </xsl:element>
        </xsl:element>
        <xsl:value-of disable-output-escaping="yes" select="string('&amp;#160;')"/>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 /////////////////////////////////////////////////////////////////
 //// Kopf- und Fuzeilen
 ///////////////////////////////////////////////////////////////// -->

<!-- Kopf- und Fuzeilen sollen an bestimmten Stellen verarbeitet werden und nicht dann wenn sie im XML-String vorkommen -->
<xsl:template match="kzinhalt | fzinhalt"><!-- nichts tun -->
</xsl:template>

<!--
<xsl:template match="fzinhalt" mode="dokumentende">
  <xsl:choose >
    <xsl:when test="./@typ='f'">
    </xsl:when>
    <xsl:when test="./@typ='p'">
      <xsl:apply-templates/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="p">
        <xsl:element name="span">
          <xsl:attribute name="class">Fehler</xsl:attribute>
          <xsl:text>Falscher Typ: Bitte melden Sie den Fehler:</xsl:text>
        </xsl:element>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
-->

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="key('key_kzinhalt_typ', 'f')" mode="dokumentanfang">
  <xsl:apply-templates/>
</xsl:template>

<!-- ///////////////////////////////////////////////////////////////// -->
<xsl:template match="key('key_fzinhalt_typ', 'f')" mode="dokumentende">
  <xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>